summaryrefslogtreecommitdiffstats
path: root/libtdepim/ktimeedit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/ktimeedit.cpp')
-rw-r--r--libtdepim/ktimeedit.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/libtdepim/ktimeedit.cpp b/libtdepim/ktimeedit.cpp
index 2a58fc54..2fe849c5 100644
--- a/libtdepim/ktimeedit.cpp
+++ b/libtdepim/ktimeedit.cpp
@@ -53,7 +53,7 @@ public:
return Intermediate;
bool ok = false;
- /*TQTime time =*/ TDEGlobal::locale()->readTime(str, KLocale::WithoutSeconds, &ok);
+ /*TQTime time =*/ TDEGlobal::locale()->readTime(str, TDELocale::WithoutSeconds, &ok);
if ( ok )
return Acceptable;
// kdDebug(5300)<<"Time "<<str<<" not directly acceptable, trying military format "<<endl;
@@ -91,7 +91,7 @@ public:
}
virtual void fixup ( TQString & input ) const {
bool ok = false;
- TDEGlobal::locale()->readTime( input, KLocale::WithoutSeconds, &ok );
+ TDEGlobal::locale()->readTime( input, TDELocale::WithoutSeconds, &ok );
if ( !ok ) {
// Also try to accept times in "military format", i.e. no delimiter, like 1200
int tm = input.toInt( &ok );
@@ -149,9 +149,9 @@ bool KTimeEdit::hasTime() const
TQTime KTimeEdit::getTime() const
{
//kdDebug(5300) << "KTimeEdit::getTime(), currentText() = " << currentText() << endl;
// TODO use KLocale::WithoutSeconds in HEAD
bool ok = false;
- TQTime time = TDEGlobal::locale()->readTime( currentText(), KLocale::WithoutSeconds, &ok );
+ TQTime time = TDEGlobal::locale()->readTime( currentText(), TDELocale::WithoutSeconds, &ok );
if ( !ok ) {
// Also try to accept times in "military format", i.e. no delimiter, like 1200
int tm = currentText().toInt( &ok );
@@ -149,9 +149,9 @@ bool KTimeEdit::hasTime() const
{
//kdDebug(5300) << "KTimeEdit::getTime(), currentText() = " << currentText() << endl;
- // TODO use KLocale::WithoutSeconds in HEAD
+ // TODO use TDELocale::WithoutSeconds in HEAD
bool ok = false;